==> Starco-2.5.9.tar.gz: Starco-2.5.9/starco/tlg/bot/util/filteres.py <==
from telegram.ext.filters import MessageFilter,UpdateFilter,BaseFilter
from.enum import Role


class match_text(MessageFilter):
    def __init__(self, target) -> None:
        super(match_text, self).__init__()
        self.target = target

    def filter(self, message):
        return self.target == message.text

class IsReplied(MessageFilter):
    def __init__(self,*args) -> None:
        super(IsReplied, self).__init__()
    def filter(self, message):
        out = message.reply_to_message!=None and message.chat.id==message.reply_to_message.chat.id
        return out

class special_user(MessageFilter):
    def __init__(self, target) -> None:
        super(special_user, self).__init__()
        self.target = target

    def filter(self, message):
        return self.target == message.from_user.id
    
class match_btn(MessageFilter):
    def __init__(self, target,super_self) -> None:
        super(match_btn, self).__init__()
        self.target = target
        self.super_self = super_self

    def filter(self, message):
        res = self.super_self.replace_btn_label(self.target, main_word= message.text) == message.text
        return res

class RoleFilter(UpdateFilter):
    def __init__(self, *super_self) -> None:
        super(RoleFilter, self).__init__(*super_self)
        # self.super_self = super_self
        print(super_self)

    # def filter(self,*args):
    #     print(self.super_self.user('role') , self.super_self.role)
    #     return self.super_self.user('role') in self.super_self.role




class RoleFilter(UpdateFilter):
    """Represents a filter that has been inverted.

    Args:
        f: The filter to invert.

    """

    __slots__ = ('f',)

    def __init__(self, f,*args):
        self.f = f

    def filter(self, update) -> bool:
        super_self = self.f
        u_id = update.message.from_user.id
        try:
            user = super_self.db.do('users',condition=f"id={u_id}")
            if user:
                res = user[0]['role'] in super_self.role
                return res
            if u_id == super_self.super_admin:
                return True
            return Role.USER.value in super_self.role
        except Exception as e:super_self.debug.debug(e)
        return True

==> Starco-2.7.5.tar.gz: Starco-2.7.5/starco/tlg/bot/util/filteres.py <==
from telegram.ext.filters import MessageFilter,UpdateFilter,BaseFilter
from.enum import Role
from telegram import Update


class match_text(MessageFilter):
    def __init__(self, target) -> None:
        super(match_text, self).__init__()
        self.target = target

    def filter(self, message):
        return self.target == message.text

class IsReplied(MessageFilter):
    def __init__(self,*args) -> None:
        super(IsReplied, self).__init__()
    def filter(self, message):
        out = message.reply_to_message!=None and message.chat.id==message.reply_to_message.chat.id
        return out

class special_user(MessageFilter):
    def __init__(self, target) -> None:
        super(special_user, self).__init__()
        self.target = target

    def filter(self, message):
        return self.target == message.from_user.id
    
class match_btn(MessageFilter):
    def __init__(self, target,super_self) -> None:
        super(match_btn, self).__init__()
        self.target = target
        self.super_self = super_self

    def filter(self, message):
        res = self.super_self.replace_btn_label(self.target, main_word= message.text) == message.text
        return res




class RoleFilter(UpdateFilter):
    """Represents a filter that has been inverted.

    Args:
        f: The filter to invert.

    """

    __slots__ = ('f',)

    def __init__(self, f,*args):
        self.f = f

    def filter(self, update) -> bool:
        super_self = self.f
        u_id = update.message.from_user.id
        try:
            user = super_self.db.do('users',condition=f"id={u_id}")
            if user:
                res = user[0]['role'] in super_self.role
                return res
            if u_id == super_self.super_admin:
                return True
            return Role.USER.value in super_self.role
        except Exception as e:super_self.debug.debug(e)
        return True

 
class FileFormat(UpdateFilter):
    """Represents a filter that has been inverted.

    Args:
        f: The filter to invert.

    """

    __slots__ = ('format')

    def __init__(self, format:str,*args):
        self.format:str = format

    def filter(self, update:Update) -> bool:
        try:
            format = self.format.lower()
            file_path =update.effective_message.effective_attachment
            if file_path:
                file_path=file_path.get_file().file_path
                file_format = file_path.split('.')[-1].lower()
                if format==file_format:
                    return True
        except Exception as e:print(e)
        return False
